@@ -1,4 +1,4 @@
-sglasso.fit <- function(Sv, mask, w, nrho, min_rho, nstep, algorithm, tol){
+sglasso.fit <- function(Sv, mask, w, nrho, min_rho, nstep, algorithm, truncate, tol){
 	out_mask2Tv <- mask2Tv(mask)
 	Tv_pkg <- out_mask2Tv$Tv_pkg
 	Tv_rw <- out_mask2Tv$Tv_rw
@@ -36,6 +36,7 @@ sglasso.fit <- function(Sv, mask, w, nrho, min_rho, nstep, algorithm, tol){
 	storage.mode(Te_scn) <- "integer"
 	storage.mode(Te_ptr_scn) <- "integer"
 	storage.mode(nstep) <- "integer"
+    storage.mode(truncate) <- "double"
 	storage.mode(tol) <- "double"
 	rho <- double(nrho)
 	storage.mode(nrho) <- "integer"
@@ -45,36 +46,33 @@ sglasso.fit <- function(Sv, mask, w, nrho, min_rho, nstep, algorithm, tol){
 	th <- matrix(0, nv + ne, nrho, dimnames = list(c(nmv, nme)))
 	storage.mode(th) <- "double"
 	storage.mode(w) <- "double"
-	df <- integer(nrho)
 	n <- integer(1)
 	conv <- integer(1)
 	if(nrho > 1){
 		if(algorithm == "ccd"){
 			fit = .Fortran("sglasso_ccd_path", nSv = nSv, Sv = Sv, nTv = nTv, Tv_pkg = Tv_pkg, Tv_rw = Tv_rw, nv = nv, 
 						   Tv_ptr = Tv_ptr, nTe = nTe, Te = Te, nTe_ptr = nTe_ptr, Te_ptr = Te_ptr,ne = ne, 
-						   Te_scn = Te_scn, Te_ptr_scn = Te_ptr_scn, nstep = nstep, tol = tol, rho = rho, 
-						   nrho = nrho, min_rho = min_rho, grd = grd, th = th, w = w, df = df, n = n, conv = conv)
+						   Te_scn = Te_scn, Te_ptr_scn = Te_ptr_scn, nstep = nstep, trnc = truncate, tol = tol, rho = rho,
+						   nrho = nrho, min_rho = min_rho, grd = grd, th = th, w = w, n = n, conv = conv)
 		} else {
 			fit = .Fortran("sglasso_ccm_path", nSv = nSv, Sv = Sv, nTv = nTv, Tv_pkg = Tv_pkg, Tv_rw = Tv_rw, nv = nv, 
 						   v_ptr = Tv_ptr, nTe = nTe, Te = Te, nTe_ptr = nTe_ptr, Te_ptr = Te_ptr,ne = ne, 
-						   Te_scn = Te_scn, Te_ptr_scn = Te_ptr_scn, nstep = nstep, tol = tol, rho = rho, 
-						   nrho = nrho, min_rho = min_rho, grd = grd, th = th, w = w, df = df, n = n, conv = conv)
+						   Te_scn = Te_scn, Te_ptr_scn = Te_ptr_scn, nstep = nstep, trnc = truncate, tol = tol, rho = rho, 
+						   nrho = nrho, min_rho = min_rho, grd = grd, th = th, w = w, n = n, conv = conv)
 		}
-		
-		
 	} else {
 		if(algorithm == "ccd"){
 			fit = .Fortran("sglasso_ccd_single", nSv = nSv, Sv = Sv, nTv = nTv, Tv_pkg = Tv_pkg, Tv_rw = Tv_rw, nv = nv, 
 						   Tv_ptr = Tv_ptr, nTe = nTe, Te = Te, nTe_ptr = nTe_ptr, Te_ptr = Te_ptr,ne = ne, 
-						   Te_scn = Te_scn, Te_ptr_scn = Te_ptr_scn, nstep = nstep, tol = tol, rho = min_rho, 
-						   grd = grd, th = th, w = w, df = df, n = n, conv = conv)
+						   Te_scn = Te_scn, Te_ptr_scn = Te_ptr_scn, nstep = nstep, trnc = truncate, tol = tol, rho = min_rho,
+						   grd = grd, th = th, w = w, n = n, conv = conv)
 		} else {
 			fit = .Fortran("sglasso_ccm_single", nSv = nSv, Sv = Sv, nTv = nTv, Tv_pkg = Tv_pkg, Tv_rw = Tv_rw, nv = nv, 
 						   Tv_ptr = Tv_ptr, nTe = nTe, Te = Te, nTe_ptr = nTe_ptr, Te_ptr = Te_ptr,ne = ne, 
-						   Te_scn = Te_scn, Te_ptr_scn = Te_ptr_scn, nstep = nstep, tol = tol, rho = min_rho, 
-						   grd = grd, th = th, w = w, df = df, n = n, conv = conv)			
+						   Te_scn = Te_scn, Te_ptr_scn = Te_ptr_scn, nstep = nstep, trnc = truncate, tol = tol, rho = min_rho,
+						   grd = grd, th = th, w = w, n = n, conv = conv)			
 		}
 	}
-	if(fit$conv!=0) warning("sglasso does not converge\n")
+	if(fit$conv!=0) warning("sglasso does not converge with code ", fit$conv, "\n")
 	fit
 }
